@@ -84,6 +84,7 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
     rows_synced = 0
 
     for record in get_shard_records(streams_client, stream_arn, shard, seq_number):
+        LOGGER.info("Record got here  : %s",record)
         if record['eventName'] == 'REMOVE':
             record_message = deserializer.deserialize_item(record['dynamodb']['Keys'])
             record_message[SDC_DELETED_AT] = singer.utils.strftime(record['dynamodb']['ApproximateCreationDateTime'])
@@ -184,9 +185,6 @@ def sync(config, state, stream):
     seq_number_bookmarks = singer.get_bookmark(state, table_name, 'shard_seq_numbers')
     if not seq_number_bookmarks:
         seq_number_bookmarks = {}
-    LOGGER.info("seq number bookmarks : %s",seq_number_bookmarks)
-    LOGGER.info("stream arn value : %s",stream_arn)
-    LOGGER.info("state : %s",state)
 
 
     # Get the list of closed shards which we have fully synced. These
@@ -255,7 +253,7 @@ def has_stream_aged_out(state, table_name):
 
     # If it has been > than 19h30m since the last successful sync of this
     # stream then we consider the stream to be aged out
-    return time_span > datetime.timedelta(hours=19, minutes=30)
+    return time_span > datetime.timedelta(hours=0, minutes=1)
 
 # Backoff for both ReadTimeout and ConnectTimeout error for 5 times
 @backoff.on_exception(backoff.expo,
